import { render, screen } from '@testing-library/react';
import LayerStack from './LayerStack';
import { CoordinateSystem } from './LiveMap';

describe('The LayerStack component', () => {
    const coordinateSystem:CoordinateSystem= {
        shift:{x:0,y:0},
        zoom:1,
    }
  test('generates four empty layers and a populated one', () => {
    // const { result } = renderHook(() => useAtom(tiledLayersAtom));
    render(
      <LayerStack
        numberOfTiledLayers={5}
        keyObject={{ provider: 'fake', zoomLevel: 9, x: 777, y: 333 }}
        coordinateSystem= {coordinateSystem}
      />
    );
    const svg = screen.getByTestId('layer-stack');
    expect(svg).toMatchInlineSnapshot(`
<svg
  data-testid="layer-stack"
  height="768"
  width="1024"
>
  <g
    transform="translate(0, 0) scale(1)"
  >
    <g
      transform="scale(1024) translate(-194.25, -83.25)"
    />
    <g
      transform="scale(512) translate(-388.5, -166.5)"
    />
    <g
      transform="scale(64) translate(-3108, -1332)"
    />
    <g
      transform="scale(128) translate(-1554, -666)"
    />
    <g
      transform="scale(256) translate(-777, -333)"
    >
      <g
        transform="translate(777, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/335.png"
          width="1"
        />
      </g>
    </g>
  </g>
</svg>
`);
  });

  test('generates two empty layers and a populated one', () => {
    // const { result } = renderHook(() => useAtom(tiledLayersAtom));
    render(
      <LayerStack
        numberOfTiledLayers={3}
        keyObject={{ provider: 'fake', zoomLevel: 9, x: 777, y: 333 }}
        coordinateSystem= {coordinateSystem}
      />
    );
    const svg = screen.getByTestId('layer-stack');
    expect(svg).toMatchInlineSnapshot(`
<svg
  data-testid="layer-stack"
  height="768"
  width="1024"
>
  <g
    transform="translate(0, 0) scale(1)"
  >
    <g
      transform="scale(512) translate(-388.5, -166.5)"
    />
    <g
      transform="scale(128) translate(-1554, -666)"
    />
    <g
      transform="scale(256) translate(-777, -333)"
    >
      <g
        transform="translate(777, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/335.png"
          width="1"
        />
      </g>
    </g>
  </g>
</svg>
`);
  });

/*   test('populates a new layer when zoomed in', () => {
    // const { result } = renderHook(() => useAtom(tiledLayersAtom));
    render(
      <LayerStack
        numberOfTiledLayers={3}
        keyObject={{ provider: 'fake', zoomLevel: 9, x: 777, y: 333 }}
        coordinateSystem= {coordinateSystem}
      />
    );
    const { result } = renderHook(() => [
      useAtom(coordinateSystemAtom),
      useAtom(relativeCoordinateSystemAtom),
    ]);
    act(() => {
      result.current[0][1]({
        shift: {
          x: 0,
          y: 0,
        },
        zoom: 1,
      } as any);
      result.current[1][1]({
        deltaShift: null,
        zoomCenter: { x: 0, y: 0 },
        deltaZoom: 2,
      } as any);
    });
    const svg = screen.getByTestId('layer-stack');
    expect(svg).toMatchInlineSnapshot(`
<svg
  data-testid="layer-stack"
  height="768"
  width="1024"
>
  <g
    transform="translate(0, 0) scale(2)"
  >
    <g
      transform="scale(128) translate(-388.5, -166.5)"
    />
    <g
      transform="scale(512) translate(-1554, -666)"
    />
    <g
      transform="scale(256) translate(-777, -333)"
    >
      <g
        transform="translate(777, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 333)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/333.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 334)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/334.png"
          width="1"
        />
      </g>
      <g
        transform="translate(777, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/265/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(778, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/266/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(779, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/267/335.png"
          width="1"
        />
      </g>
      <g
        transform="translate(780, 335)"
      >
        <image
          height="1"
          href="https://fakeurl/9/268/335.png"
          width="1"
        />
      </g>
    </g>
  </g>
</svg>
`);
  }); */
});
