import { putNewTrkseg } from './trkseg';

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The trkseg module', () => {
  beforeEach(() => {
    globalThis.db = { put: jest.fn() };
    globalThis.Date.now = () => 0;
  });
  afterEach(() => {
    globalThis.db = originalDb;
    globalThis.Date.now = originalDateNow;
  });
  test('db.put() a new trk when required', async () => {
    putNewTrkseg({ gpx: 'gpxId', trk: 'trkid', trkseg: 'trksegid' });
    await expect(globalThis.db.put).toBeCalledWith({
      _id: 'gpx/gpxId/2trk/trkid/trksegid',
      _rev: undefined,
      doc: {
        trkpt: undefined,
        extensions: undefined,
      },
      type: 'trkseg',
    });
  });
  test('db.put() generates an id for the trk if needed', async () => {
    const id = await putNewTrkseg({ gpx: 'gpxId' });
    expect(id).toEqual({ gpx: 'gpxId', trk: '00000', trkseg: '00000' });
  });
  test('db.put() generates ids for both gpx and trk if needed', async () => {
    const id = await putNewTrkseg();
    expect(id).toEqual({ gpx: '0', trk: '00000', trkseg: '00000' });
  });
});
