import { putNewWpt } from './wpt';

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The wpt module', () => {
  beforeEach(() => {
    globalThis.db = { put: jest.fn() };
    globalThis.Date.now = () => 0;
  });
  afterEach(() => {
    globalThis.db = originalDb;
    globalThis.Date.now = originalDateNow;
  });
  test('db.put() a new wpt when required', async () => {
    putNewWpt({ gpx: 'gpxId', wpt: 'wptid' });
    await expect(globalThis.db.put).toBeCalledWith({
      _id: 'gpx/gpxId/0wpt/wptid',
      _rev: undefined,
      doc: {
        $: { lat: 0, lon: 0 },
        ageofdgpsdata: undefined,
        cmt: undefined,
        desc: undefined,
        dgpsid: undefined,
        ele: undefined,
        extensions: undefined,
        fix: undefined,
        geoidheight: undefined,
        hdop: undefined,
        link: undefined,
        magvar: undefined,
        name: undefined,
        pdop: undefined,
        sat: undefined,
        src: undefined,
        sym: undefined,
        time: undefined,
        type: undefined,
        vdop: undefined,
      },
      type: 'wpt',
    });
  });
  test('db.put() generates an id for the wpt if needed', async () => {
    const id = await putNewWpt({ gpx: 'gpxId' });
    expect(id).toEqual({ gpx: 'gpxId', wpt: '00000' });
  });
  test('db.put() generates ids for both gpx and trk if needed', async () => {
    const id = await putNewWpt();
    expect(id).toEqual({ gpx: '0', wpt: '00000' });
  });
});
